@@ -1,6 +1,7 @@
 from unittest import main, TestCase
 
 from checking.asserts import *
+from checking.context import *
 from checking.annotations import test
 from checking.runner import start
 from checking.classes.basic_suite import TestSuite
@@ -18,7 +19,7 @@ class TestAssertsBehaviour(TestCase):
 
     def test_wait_exception_test_broken_if_BaseException(self):
         def fn():
-            with waiting_exception(BaseException):
+            with should_raise(BaseException):
                 print()
 
         _run(fn)
@@ -26,7 +27,7 @@ class TestAssertsBehaviour(TestCase):
 
     def test_wait_success_test_if_Exception(self):
         def fn():
-            with waiting_exception(Exception):
+            with should_raise(Exception):
                 x = 1 / 0
 
         _run(fn)
@@ -35,7 +36,7 @@ class TestAssertsBehaviour(TestCase):
 
     def test_wait_success_test_if_concrete_exception(self):
         def fn():
-            with waiting_exception(ZeroDivisionError):
+            with should_raise(ZeroDivisionError):
                 x = 1 / 0
 
         _run(fn)
@@ -44,7 +45,7 @@ class TestAssertsBehaviour(TestCase):
 
     def test_wait_broken_test_if_use_non_exception_type(self):
         def fn():
-            with waiting_exception('wrong'):
+            with should_raise('wrong'):
                 x = 1 / 0
 
         _run(fn)
@@ -53,7 +54,7 @@ class TestAssertsBehaviour(TestCase):
 
     def test_wait_failed_test_if_non_raised(self):
         def fn():
-            with waiting_exception(Exception):
+            with should_raise(Exception):
                 pass
 
         _run(fn)
@@ -62,7 +63,7 @@ class TestAssertsBehaviour(TestCase):
 
     def test_wait_failed_test_if_another_raised(self):
         def fn():
-            with waiting_exception(ZeroDivisionError):
+            with should_raise(ZeroDivisionError):
                 int('a')
 
         _run(fn)
@@ -101,13 +102,13 @@ class TestAssertsBehaviour(TestCase):
         self.assertEqual(1, len(TestSuite.get_instance().failed()))
 
     def test_not_none_positive(self):
-        _run(lambda: not_none(1))
+        _run(lambda: is_not_none(1))
         self.assertEqual(0, len(TestSuite.get_instance().broken()))
         self.assertEqual(1, len(TestSuite.get_instance().success()))
         self.assertEqual(0, len(TestSuite.get_instance().failed()))
 
     def test_not_none_negative(self):
-        _run(lambda: not_none(None))
+        _run(lambda: is_not_none(None))
         self.assertEqual(0, len(TestSuite.get_instance().broken()))
         self.assertEqual(0, len(TestSuite.get_instance().success()))
         self.assertEqual(1, len(TestSuite.get_instance().failed()))
