@@ -1,8 +1,8 @@
 from unittest import main, TestCase
 
 from checking.annotations import *
+import checking.runner as runner
 from checking.runner import start
-from checking.runner import common_parameters
 from checking.classes.listeners.basic import Listener
 
 common_str = ''
@@ -13,11 +13,11 @@ def failed():
 
 
 def par_1():
-    common_parameters['1'] = 1
+    runner.common['1'] = 1
 
 
 def par_2():
-    assert 1 == common_parameters['1']
+    assert 1 == runner.common['1']
 
 
 def clear():
@@ -27,9 +27,11 @@ def clear():
     test_suite.after.clear()
     test_suite.is_before_failed = False
     test_suite.providers.clear()
+    test_suite.cache.clear()
+    test_suite.cached.clear()
     global common_str
     common_str = ''
-    common_parameters.clear()
+    runner.common.clear()
 
 
 def b_suite():
@@ -254,7 +256,7 @@ class TestBeforeAndAfter(TestCase):
         test(par_1)
         test(par_2)
         start(listener=self._listener)
-        self.assertEqual(common_parameters, {'1': 1})
+        self.assertEqual(runner.common.as_dict(), {'1': 1})
 
     def test_no_tests_if_filter_not_existed_group(self):
         clear()
@@ -274,22 +276,57 @@ class TestBeforeAndAfter(TestCase):
         clear()
         test(fn)
         start(listener=self._listener)
-        self.assertFalse(common_parameters)
+        self.assertFalse(runner.common)
 
     def test_params_if_exists(self):
         clear()
         test(fn)
         start(listener=self._listener, params={'test': 'test'})
-        self.assertTrue(common_parameters)
-        self.assertEqual(common_parameters, {'test': 'test'})
+        self.assertTrue(runner.common)
+        self.assertEqual(runner.common.as_dict(), {'test': 'test'})
 
     def test_params_if_exists_and_use_in_test(self):
         clear()
         test(par_1)
         start(listener=self._listener, params={'test': 'test'})
-        self.assertTrue(common_parameters)
-        self.assertEqual('test', common_parameters['test'])
-        self.assertEqual(1, common_parameters['1'])
+        self.assertTrue(runner.common)
+        self.assertEqual('test', runner.common['test'])
+        self.assertEqual(1, runner.common['1'])
+
+    def test_common_function_works(self):
+        def name():
+            pass
+
+        clear()
+        common_function(name)
+        test(failed)
+        start(listener=self._listener)
+        self.assertTrue(runner.common)
+        self.assertEqual(name, runner.common.name)
+        self.assertEqual(name, runner.common['name'])
+
+    def test_common_function_works_with_params(self):
+        def name():
+            pass
+
+        clear()
+        common_function(name)
+        test(failed)
+        start(listener=self._listener, params={'test': 'test'})
+        self.assertTrue(runner.common)
+        self.assertEqual(name, runner.common.name)
+        self.assertEqual('test', runner.common.test)
+        self.assertEqual(2, len(runner.common.as_dict()))
+
+    def test_common_function_raises_on_second_use_of_name(self):
+        def name():
+            pass
+
+        clear()
+        common_function(name)
+        with self.assertRaises(WrongDecoratedObject) as e:
+            common_function(name)
+        self.assertEqual(e.exception.args[0], 'Name "name" is already used at common object')
 
 
 if __name__ == '__main__':
